//---------------------------------------------------------------------------
#ifndef SPgpH
#define SPgpH
//---------------------------------------------------------------------------
#include <vcl\SysUtils.hpp>
#include <vcl\Controls.hpp>
#include <vcl\Classes.hpp>
#include <vcl\Forms.hpp>
#include <vcl/dsgnintf.hpp>

// PGP include
// functions
#define PGP_DECRYPT		0x0001
#define PGP_ENCRYPT		0x0002
#define PGP_SIGN			0x0004
#define PGP_ASCII			0x0008
#define PGP_COMPRESS		0x0010
#define PGP_TEXT			0x0020
#define PGP_STRINGIN		0x0040
#define PGP_STRINGOUT	0x0080

// Return values
#define PGP_RET_GOODSIG				0x0001
#define PGP_RET_BADSIG				0x0002

// Errors
#define PGP_ERR_PUBFILE				(-1)
#define PGP_ERR_SECFILE				(-2)
#define PGP_ERR_INFILE 				(-3)
#define PGP_ERR_OUTFILE				(-4)
#define PGP_ERR_PUBKEYNOTFOUND	(-5)
#define PGP_ERR_SECKEYNOTFOUND	(-6)
#define PGP_ERR_KEYMISSING			(-7)
#define PGP_ERR_NOTPGP				(-8)
#define PGP_ERR_PGPCORRUPT			(-9)
#define PGP_ERR_BADPASSPHRASE		(-10)
#define PGP_ERR_BADSIGNATURE		(-11)
#define PGP_ERR_WRONGIDEAKEY		(-12)
#define PGP_ERR_BUFTOOSMALL		(-13)


class TPGPFile : public TPersistent
{
private:
	AnsiString FFileName;
public:
	__fastcall TPGPFile();
__published:
	__property AnsiString FileName = {read=FFileName, write=FFileName};
};

//---------------------------------------------------------------------------
class TPGPProperty : public TClassProperty
{
public:
	virtual TPropertyAttributes __fastcall GetAttributes(void);
	virtual void __fastcall Edit(void);
	AnsiString __fastcall GetValue();
    void __fastcall SetValue(AnsiString Value);
public:
	__fastcall virtual TPGPProperty(void);
	__fastcall virtual ~TPGPProperty(void);
};

//---------------------------------------------------------------------------
class TSPgp : public TComponent
{
private:
	TPGPFile *FPublicKeyFile;
    TPGPFile *FSecretKeyFile;
    AnsiString FEncryptionKey;
    AnsiString FPassPhrase;
protected:
public:
	__fastcall TSPgp(TComponent* Owner);
    __fastcall ~TSPgp();
    int __fastcall Pgp(int function, char *input, int insize, char *output,	int *outsize);
__published:
    __property TPGPFile *PublicKeyFile = {read=FPublicKeyFile, write=FPublicKeyFile};
    __property TPGPFile *SecretKeyFile = {read=FSecretKeyFile, write=FSecretKeyFile};
    __property AnsiString EncryptionKey = {read=FEncryptionKey, write=FEncryptionKey, nodefault};
    __property AnsiString PassPhrase = {read=FPassPhrase, write=FPassPhrase};
};
//---------------------------------------------------------------------------
#endif
